==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/scvmm/kotlin/inputs/NetworkInterfacesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.scvmm.kotlin.inputs

import com.pulumi.azurenative.scvmm.inputs.NetworkInterfacesArgs.builder
import com.pulumi.azurenative.scvmm.kotlin.enums.AllocationMethod
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Network Interface model
 * @property ipv4AddressType Gets or sets the ipv4 address type.
 * @property ipv6AddressType Gets or sets the ipv6 address type.
 * @property macAddress Gets or sets the nic MAC address.
 * @property macAddressType Gets or sets the mac address type.
 * @property name Gets or sets the name of the network interface.
 * @property nicId Gets or sets the nic id.
 * @property virtualNetworkId Gets or sets the ARM Id of the Microsoft.ScVmm/virtualNetwork resource to connect the nic.
 */
public data class NetworkInterfacesArgs(
    public val ipv4AddressType: Output<Either<String, AllocationMethod>>? = null,
    public val ipv6AddressType: Output<Either<String, AllocationMethod>>? = null,
    public val macAddress: Output<String>? = null,
    public val macAddressType: Output<Either<String, AllocationMethod>>? = null,
    public val name: Output<String>? = null,
    public val nicId: Output<String>? = null,
    public val virtualNetworkId: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.scvmm.inputs.NetworkInterfacesArgs> {
    override fun toJava(): com.pulumi.azurenative.scvmm.inputs.NetworkInterfacesArgs =
        com.pulumi.azurenative.scvmm.inputs.NetworkInterfacesArgs.builder()
            .ipv4AddressType(
                ipv4AddressType?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .ipv6AddressType(
                ipv6AddressType?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .macAddress(macAddress?.applyValue({ args0 -> args0 }))
            .macAddressType(
                macAddressType?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .name(name?.applyValue({ args0 -> args0 }))
            .nicId(nicId?.applyValue({ args0 -> args0 }))
            .virtualNetworkId(virtualNetworkId?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [NetworkInterfacesArgs].
 */
@PulumiTagMarker
public class NetworkInterfacesArgsBuilder internal constructor() {
    private var ipv4AddressType: Output<Either<String, AllocationMethod>>? = null

    private var ipv6AddressType: Output<Either<String, AllocationMethod>>? = null

    private var macAddress: Output<String>? = null

    private var macAddressType: Output<Either<String, AllocationMethod>>? = null

    private var name: Output<String>? = null

    private var nicId: Output<String>? = null

    private var virtualNetworkId: Output<String>? = null

    /**
     * @param value Gets or sets the ipv4 address type.
     */
    @JvmName("xdvmgvoevonxkiua")
    public suspend fun ipv4AddressType(`value`: Output<Either<String, AllocationMethod>>) {
        this.ipv4AddressType = value
    }

    /**
     * @param value Gets or sets the ipv6 address type.
     */
    @JvmName("bqqaapfuxlnocjcu")
    public suspend fun ipv6AddressType(`value`: Output<Either<String, AllocationMethod>>) {
        this.ipv6AddressType = value
    }

    /**
     * @param value Gets or sets the nic MAC address.
     */
    @JvmName("gjrckpgvgvkhfmym")
    public suspend fun macAddress(`value`: Output<String>) {
        this.macAddress = value
    }

    /**
     * @param value Gets or sets the mac address type.
     */
    @JvmName("xovqljpufxobtqot")
    public suspend fun macAddressType(`value`: Output<Either<String, AllocationMethod>>) {
        this.macAddressType = value
    }

    /**
     * @param value Gets or sets the name of the network interface.
     */
    @JvmName("bxbuuiemmaikckms")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value Gets or sets the nic id.
     */
    @JvmName("uahuiuxroltssmck")
    public suspend fun nicId(`value`: Output<String>) {
        this.nicId = value
    }

    /**
     * @param value Gets or sets the ARM Id of the Microsoft.ScVmm/virtualNetwork resource to connect the nic.
     */
    @JvmName("scujdiwboqkmiqhs")
    public suspend fun virtualNetworkId(`value`: Output<String>) {
        this.virtualNetworkId = value
    }

    /**
     * @param value Gets or sets the ipv4 address type.
     */
    @JvmName("ruynmmfevuuegvhl")
    public suspend fun ipv4AddressType(`value`: Either<String, AllocationMethod>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.ipv4AddressType = mapped
    }

    /**
     * @param value Gets or sets the ipv4 address type.
     */
    @JvmName("euhwqlacgqtoteyk")
    public fun ipv4AddressType(`value`: String) {
        val toBeMapped = Either.ofLeft<String, AllocationMethod>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.ipv4AddressType = mapped
    }

    /**
     * @param value Gets or sets the ipv4 address type.
     */
    @JvmName("oqgqddppwdlxtkgn")
    public fun ipv4AddressType(`value`: AllocationMethod) {
        val toBeMapped = Either.ofRight<String, AllocationMethod>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.ipv4AddressType = mapped
    }

    /**
     * @param value Gets or sets the ipv6 address type.
     */
    @JvmName("gomgqdlfygdcvfrn")
    public suspend fun ipv6AddressType(`value`: Either<String, AllocationMethod>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.ipv6AddressType = mapped
    }

    /**
     * @param value Gets or sets the ipv6 address type.
     */
    @JvmName("hfpbjmoidffytkdr")
    public fun ipv6AddressType(`value`: String) {
        val toBeMapped = Either.ofLeft<String, AllocationMethod>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.ipv6AddressType = mapped
    }

    /**
     * @param value Gets or sets the ipv6 address type.
     */
    @JvmName("yopvekktbfnoqsuu")
    public fun ipv6AddressType(`value`: AllocationMethod) {
        val toBeMapped = Either.ofRight<String, AllocationMethod>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.ipv6AddressType = mapped
    }

    /**
     * @param value Gets or sets the nic MAC address.
     */
    @JvmName("kawyrpyjqinuclkn")
    public suspend fun macAddress(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.macAddress = mapped
    }

    /**
     * @param value Gets or sets the mac address type.
     */
    @JvmName("tnflnfgededicwib")
    public suspend fun macAddressType(`value`: Either<String, AllocationMethod>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.macAddressType = mapped
    }

    /**
     * @param value Gets or sets the mac address type.
     */
    @JvmName("fhxxowatpqdkjowi")
    public fun macAddressType(`value`: String) {
        val toBeMapped = Either.ofLeft<String, AllocationMethod>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.macAddressType = mapped
    }

    /**
     * @param value Gets or sets the mac address type.
     */
    @JvmName("bcxmnqpirsieabve")
    public fun macAddressType(`value`: AllocationMethod) {
        val toBeMapped = Either.ofRight<String, AllocationMethod>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.macAddressType = mapped
    }

    /**
     * @param value Gets or sets the name of the network interface.
     */
    @JvmName("cgfuognyglcbjawb")
    public suspend fun name(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value Gets or sets the nic id.
     */
    @JvmName("inqofgtmljnjtoym")
    public suspend fun nicId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.nicId = mapped
    }

    /**
     * @param value Gets or sets the ARM Id of the Microsoft.ScVmm/virtualNetwork resource to connect the nic.
     */
    @JvmName("qhmsnhldhukabduv")
    public suspend fun virtualNetworkId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.virtualNetworkId = mapped
    }

    internal fun build(): NetworkInterfacesArgs = NetworkInterfacesArgs(
        ipv4AddressType = ipv4AddressType,
        ipv6AddressType = ipv6AddressType,
        macAddress = macAddress,
        macAddressType = macAddressType,
        name = name,
        nicId = nicId,
        virtualNetworkId = virtualNetworkId,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/scvmm/kotlin/inputs/NetworkInterfacesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.scvmm.kotlin.inputs

import com.pulumi.azurenative.scvmm.inputs.NetworkInterfacesArgs.builder
import com.pulumi.azurenative.scvmm.kotlin.enums.AllocationMethod
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Network Interface model
 * @property ipv4AddressType Gets or sets the ipv4 address type.
 * @property ipv6AddressType Gets or sets the ipv6 address type.
 * @property macAddress Gets or sets the nic MAC address.
 * @property macAddressType Gets or sets the mac address type.
 * @property name Gets or sets the name of the network interface.
 * @property nicId Gets or sets the nic id.
 * @property virtualNetworkId Gets or sets the ARM Id of the Microsoft.ScVmm/virtualNetwork resource to connect the nic.
 */
public data class NetworkInterfacesArgs(
    public val ipv4AddressType: Output<Either<String, AllocationMethod>>? = null,
    public val ipv6AddressType: Output<Either<String, AllocationMethod>>? = null,
    public val macAddress: Output<String>? = null,
    public val macAddressType: Output<Either<String, AllocationMethod>>? = null,
    public val name: Output<String>? = null,
    public val nicId: Output<String>? = null,
    public val virtualNetworkId: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.scvmm.inputs.NetworkInterfacesArgs> {
    override fun toJava(): com.pulumi.azurenative.scvmm.inputs.NetworkInterfacesArgs =
        com.pulumi.azurenative.scvmm.inputs.NetworkInterfacesArgs.builder()
            .ipv4AddressType(
                ipv4AddressType?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .ipv6AddressType(
                ipv6AddressType?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .macAddress(macAddress?.applyValue({ args0 -> args0 }))
            .macAddressType(
                macAddressType?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .name(name?.applyValue({ args0 -> args0 }))
            .nicId(nicId?.applyValue({ args0 -> args0 }))
            .virtualNetworkId(virtualNetworkId?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [NetworkInterfacesArgs].
 */
@PulumiTagMarker
public class NetworkInterfacesArgsBuilder internal constructor() {
    private var ipv4AddressType: Output<Either<String, AllocationMethod>>? = null

    private var ipv6AddressType: Output<Either<String, AllocationMethod>>? = null

    private var macAddress: Output<String>? = null

    private var macAddressType: Output<Either<String, AllocationMethod>>? = null

    private var name: Output<String>? = null

    private var nicId: Output<String>? = null

    private var virtualNetworkId: Output<String>? = null

    /**
     * @param value Gets or sets the ipv4 address type.
     */
    @JvmName("owtemgxfhgstvjty")
    public suspend fun ipv4AddressType(`value`: Output<Either<String, AllocationMethod>>) {
        this.ipv4AddressType = value
    }

    /**
     * @param value Gets or sets the ipv6 address type.
     */
    @JvmName("qofbnxaxetrnauof")
    public suspend fun ipv6AddressType(`value`: Output<Either<String, AllocationMethod>>) {
        this.ipv6AddressType = value
    }

    /**
     * @param value Gets or sets the nic MAC address.
     */
    @JvmName("bvxroceahaugupyh")
    public suspend fun macAddress(`value`: Output<String>) {
        this.macAddress = value
    }

    /**
     * @param value Gets or sets the mac address type.
     */
    @JvmName("rohkhvrycbjoayum")
    public suspend fun macAddressType(`value`: Output<Either<String, AllocationMethod>>) {
        this.macAddressType = value
    }

    /**
     * @param value Gets or sets the name of the network interface.
     */
    @JvmName("spgaloxpuclascka")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value Gets or sets the nic id.
     */
    @JvmName("butkjawgypnrcnmh")
    public suspend fun nicId(`value`: Output<String>) {
        this.nicId = value
    }

    /**
     * @param value Gets or sets the ARM Id of the Microsoft.ScVmm/virtualNetwork resource to connect the nic.
     */
    @JvmName("powxuyhylldiwxqr")
    public suspend fun virtualNetworkId(`value`: Output<String>) {
        this.virtualNetworkId = value
    }

    /**
     * @param value Gets or sets the ipv4 address type.
     */
    @JvmName("ttewqewdabcxduoi")
    public suspend fun ipv4AddressType(`value`: Either<String, AllocationMethod>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.ipv4AddressType = mapped
    }

    /**
     * @param value Gets or sets the ipv4 address type.
     */
    @JvmName("ndvwhktsbwcsqxkp")
    public fun ipv4AddressType(`value`: String) {
        val toBeMapped = Either.ofLeft<String, AllocationMethod>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.ipv4AddressType = mapped
    }

    /**
     * @param value Gets or sets the ipv4 address type.
     */
    @JvmName("pdtlymtlnnunutli")
    public fun ipv4AddressType(`value`: AllocationMethod) {
        val toBeMapped = Either.ofRight<String, AllocationMethod>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.ipv4AddressType = mapped
    }

    /**
     * @param value Gets or sets the ipv6 address type.
     */
    @JvmName("iitjyabeyrteadqa")
    public suspend fun ipv6AddressType(`value`: Either<String, AllocationMethod>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.ipv6AddressType = mapped
    }

    /**
     * @param value Gets or sets the ipv6 address type.
     */
    @JvmName("fexvhvpjjnmisseh")
    public fun ipv6AddressType(`value`: String) {
        val toBeMapped = Either.ofLeft<String, AllocationMethod>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.ipv6AddressType = mapped
    }

    /**
     * @param value Gets or sets the ipv6 address type.
     */
    @JvmName("pecoymuiutwtefbo")
    public fun ipv6AddressType(`value`: AllocationMethod) {
        val toBeMapped = Either.ofRight<String, AllocationMethod>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.ipv6AddressType = mapped
    }

    /**
     * @param value Gets or sets the nic MAC address.
     */
    @JvmName("jcmkjcyktqyiadgh")
    public suspend fun macAddress(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.macAddress = mapped
    }

    /**
     * @param value Gets or sets the mac address type.
     */
    @JvmName("denwgqqsljeqsjax")
    public suspend fun macAddressType(`value`: Either<String, AllocationMethod>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.macAddressType = mapped
    }

    /**
     * @param value Gets or sets the mac address type.
     */
    @JvmName("tuofdeacdpxpvcjg")
    public fun macAddressType(`value`: String) {
        val toBeMapped = Either.ofLeft<String, AllocationMethod>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.macAddressType = mapped
    }

    /**
     * @param value Gets or sets the mac address type.
     */
    @JvmName("qqlmgrptjcypqubl")
    public fun macAddressType(`value`: AllocationMethod) {
        val toBeMapped = Either.ofRight<String, AllocationMethod>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.macAddressType = mapped
    }

    /**
     * @param value Gets or sets the name of the network interface.
     */
    @JvmName("olucyvtshtoyprpu")
    public suspend fun name(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value Gets or sets the nic id.
     */
    @JvmName("fouapmamwgnxqhxk")
    public suspend fun nicId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.nicId = mapped
    }

    /**
     * @param value Gets or sets the ARM Id of the Microsoft.ScVmm/virtualNetwork resource to connect the nic.
     */
    @JvmName("ysrkuedsqihmcdhi")
    public suspend fun virtualNetworkId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.virtualNetworkId = mapped
    }

    internal fun build(): NetworkInterfacesArgs = NetworkInterfacesArgs(
        ipv4AddressType = ipv4AddressType,
        ipv6AddressType = ipv6AddressType,
        macAddress = macAddress,
        macAddressType = macAddressType,
        name = name,
        nicId = nicId,
        virtualNetworkId = virtualNetworkId,
    )
}
